@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1997-2004, Michael Jennings
+ * Copyright (C) 1997-2009, Michael Jennings
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -21,7 +21,7 @@
  * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  */
 
-static const char cvs_ident[] = "$Id: e.c,v 1.25 2004/01/11 22:10:29 mej Exp $";
+static const char cvs_ident[] = "$Id: e.c 51650 2010-08-26 01:34:13Z lucas $";
 
 #include "config.h"
 #include "feature.h"
@@ -64,7 +64,6 @@ check_for_enlightenment(void)
 Window
 enl_ipc_get_win(void)
 {
-
     unsigned char *str = NULL;
     Atom prop;
     unsigned long num, after;
@@ -75,7 +74,7 @@ enl_ipc_get_win(void)
 
     D_ENL(("Searching for IPC window.\n"));
 
-    if (props[PROP_ENL_COMMS] == None) {
+    if ((props[PROP_ENL_COMMS] == None) || (props[PROP_ENL_VERSION] == None)) {
         D_ENL((" -> Enlightenment is not running.  You lose!\n"));
         return None;
     }
@@ -85,13 +84,45 @@ enl_ipc_get_win(void)
         XFree(str);
     }
     if (ipc_win != None) {
-        if (!XGetGeometry(Xdisplay, ipc_win, &dummy_win, &dummy_int, &dummy_int, &dummy_uint, &dummy_uint, &dummy_uint, &dummy_uint)) {
+        XGetWindowProperty(Xdisplay, Xroot, props[PROP_ENL_VERSION], 0, 14, False, AnyPropertyType,
+                           &prop, &format, &num, &after, &str);
+        if (str) {
+            char *ver, *tmp;
+
+            tmp = strchr((char *) str, ' ');
+            if (!tmp) {
+                tmp = strchr((char *) str, '-');
+            }
+            if (tmp) {
+                ver = tmp + 1;
+                tmp = strchr((char *) ver, ' ');
+                if (! tmp) {
+                    tmp = strchr((char *) ver, '-');
+                }
+                if (tmp) {
+                    *tmp = 0;
+                }
+
+                /* Make sure the version string is within the acceptable range. */
+                if (SPIF_CMP_IS_LESS(spiftool_version_compare((spif_charptr_t) str, (spif_charptr_t) "0.16.4"))
+                    || SPIF_CMP_IS_GREATER(spiftool_version_compare((spif_charptr_t) str, (spif_charptr_t) "0.16.999"))) {
+                    D_ENL((" -> IPC version string \"%s\" out of range.  I'll have to ignore it.\n"));
+                    ipc_win = None;
+                }
+            }
+            XFree(str);
+        }
+    }
+    if (ipc_win != None) {
+        if (!XGetGeometry
+            (Xdisplay, ipc_win, &dummy_win, &dummy_int, &dummy_int, &dummy_uint, &dummy_uint, &dummy_uint, &dummy_uint)) {
             D_ENL((" -> IPC Window property is valid, but the window doesn't exist.  I give up!\n"));
             ipc_win = None;
         }
         str = NULL;
         if (ipc_win != None) {
-            XGetWindowProperty(Xdisplay, ipc_win, props[PROP_ENL_COMMS], 0, 14, False, AnyPropertyType, &prop, &format, &num, &after, &str);
+            XGetWindowProperty(Xdisplay, ipc_win, props[PROP_ENL_COMMS], 0, 14, False, AnyPropertyType, &prop, &format, &num,
+                               &after, &str);
             if (str) {
                 XFree(str);
             } else {
@@ -125,12 +156,12 @@ enl_ipc_send(char *str)
     unsigned short len;
     XEvent ev;
 
-    if (str == NULL) {
+    if (!str) {
         ASSERT(last_msg != NULL);
         str = last_msg;
         D_ENL(("Resending last message \"%s\" to Enlightenment.\n", str));
     } else {
-        if (last_msg != NULL) {
+        if (last_msg) {
             FREE(last_msg);
         }
         last_msg = STRDUP(str);
@@ -215,7 +246,7 @@ enl_ipc_get(const char *msg_data)
     }
     buff[12] = 0;
     blen = strlen(buff);
-    if (message != NULL) {
+    if (message) {
         len += blen;
         message = (char *) REALLOC(message, len + 1);
         strcat(message, buff);
