@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1997-2004, Michael Jennings
+ * Copyright (C) 1997-2009, Michael Jennings
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -42,9 +42,13 @@
 
 /* These are subscripts for the arrays in a fontshadow_t */
 #define SHADOW_TOP_LEFT      0
-#define SHADOW_TOP_RIGHT     1
-#define SHADOW_BOTTOM_LEFT   2
-#define SHADOW_BOTTOM_RIGHT  3
+#define SHADOW_TOP           1
+#define SHADOW_TOP_RIGHT     2
+#define SHADOW_LEFT          3
+#define SHADOW_RIGHT         4
+#define SHADOW_BOTTOM_LEFT   5
+#define SHADOW_BOTTOM        6
+#define SHADOW_BOTTOM_RIGHT  7
 
 /* The macros are used to advance to the next/previous font as with Ctrl-> and Ctrl-< */
 #define NEXT_FONT(i)   do { if (font_idx + ((i)?(i):1) >= font_cnt) {font_idx = font_cnt - 1;} else {font_idx += ((i)?(i):1);} \
@@ -67,8 +71,8 @@ typedef struct cachefont_struct {
 } cachefont_t;
 
 typedef struct fontshadow_struct {
-  Pixel color[4];
-  unsigned char shadow[4];
+  Pixel color[8];
+  unsigned char shadow[8];
   unsigned char do_shadow;
 } fontshadow_t;
 
@@ -97,7 +101,7 @@ extern void change_font(int, const char *);
 extern const char *get_font_name(void *);
 extern void set_shadow_color_by_name(unsigned char, const char *);
 extern void set_shadow_color_by_pixel(unsigned char, Pixel);
-extern unsigned char parse_font_fx(const char *line);
+extern unsigned char parse_font_fx(char *line);
 
 _XFUNCPROTOEND
 
