@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1997-2004, Michael Jennings
+ * Copyright (C) 1997-2009, Michael Jennings
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -21,7 +21,7 @@
  * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  */
 
-static const char cvs_ident[] = "$Id: misc.c,v 1.25 2004/01/11 22:10:29 mej Exp $";
+static const char cvs_ident[] = "$Id: misc.c 51650 2010-08-26 01:34:13Z lucas $";
 
 #include "config.h"
 #include "feature.h"
@@ -75,12 +75,12 @@ char *
 str_trim(char *str)
 {
 
-    register char *tmp = str;
+    register spif_charptr_t tmp = (spif_charptr_t) str;
     size_t n;
 
     if (str && *str) {
 
-        chomp(str);
+        spiftool_chomp(str);
         n = strlen(str);
 
         if (!n) {
@@ -143,64 +143,64 @@ parse_escaped_string(char *str)
         }
         D_STRINGS(("Operating on \'%c\'\n", *pold));
         switch (*pold) {
-          case '\\':
-              D_STRINGS(("Backslash + %c\n", *(pold + 1)));
-              switch (tolower(*(++pold))) {
-                case '0':
-                case '1':
-                case '2':
-                case '3':
-                case '4':
-                case '5':
-                case '6':
-                case '7':
-                    for (i = 0; *pold >= '0' && *pold <= '7'; pold++) {
-                        i = (i * 8) + (*pold - '0');
-                    }
-                    pold--;
-                    D_STRINGS(("Octal number evaluates to %d\n", i));
-                    *pnew = i;
-                    break;
-                case 'n':
-                    *pnew = '\n';
-                    break;
-                case 'r':
-                    *pnew = '\r';
-                    break;
-                case 't':
-                    *pnew = '\t';
-                    break;
-                case 'b':
-                    *pnew = '\b';
-                    break;
-                case 'f':
-                    *pnew = '\f';
-                    break;
-                case 'a':
-                    *pnew = '\a';
-                    break;
-                case 'v':
-                    *pnew = '\v';
-                    break;
-                case 'e':
-                    *pnew = '\033';
-                    break;
-                case 'c':
-                    pold++;
-                    *pnew = MAKE_CTRL_CHAR(*pold);
-                    break;
-                default:
-                    *pnew = *pold;
-                    break;
-              }
-              break;
-          case '^':
-              D_STRINGS(("Caret + %c\n", *(pold + 1)));
-              pold++;
-              *pnew = MAKE_CTRL_CHAR(*pold);
-              break;
-          default:
-              *pnew = *pold;
+            case '\\':
+                D_STRINGS(("Backslash + %c\n", *(pold + 1)));
+                switch (tolower(*(++pold))) {
+                    case '0':
+                    case '1':
+                    case '2':
+                    case '3':
+                    case '4':
+                    case '5':
+                    case '6':
+                    case '7':
+                        for (i = 0; *pold >= '0' && *pold <= '7'; pold++) {
+                            i = (i * 8) + (*pold - '0');
+                        }
+                        pold--;
+                        D_STRINGS(("Octal number evaluates to %d\n", i));
+                        *pnew = i;
+                        break;
+                    case 'n':
+                        *pnew = '\n';
+                        break;
+                    case 'r':
+                        *pnew = '\r';
+                        break;
+                    case 't':
+                        *pnew = '\t';
+                        break;
+                    case 'b':
+                        *pnew = '\b';
+                        break;
+                    case 'f':
+                        *pnew = '\f';
+                        break;
+                    case 'a':
+                        *pnew = '\a';
+                        break;
+                    case 'v':
+                        *pnew = '\v';
+                        break;
+                    case 'e':
+                        *pnew = '\033';
+                        break;
+                    case 'c':
+                        pold++;
+                        *pnew = MAKE_CTRL_CHAR(*pold);
+                        break;
+                    default:
+                        *pnew = *pold;
+                        break;
+                }
+                break;
+            case '^':
+                D_STRINGS(("Caret + %c\n", *(pold + 1)));
+                pold++;
+                *pnew = MAKE_CTRL_CHAR(*pold);
+                break;
+            default:
+                *pnew = *pold;
         }
     }
 
@@ -216,13 +216,60 @@ parse_escaped_string(char *str)
 #if DEBUG >= DEBUG_STRINGS
     if (DEBUG_LEVEL >= DEBUG_STRINGS) {
         D_STRINGS(("New value is:\n"));
-        hex_dump(str, (size_t) (pnew - str));
+        spiftool_hex_dump(str, (size_t) (pnew - str));
     }
 #endif
 
     return (pnew - str);
 }
 
+spif_charptr_t
+escape_string(spif_charptr_t str, spif_char_t quote, spif_int32_t maxlen)
+{
+    spif_charptr_t buff, s = str, pbuff;
+
+    D_STRINGS(("escape_string(%s %c %ld)\n", (char *) str, quote, maxlen));
+    if (!quote) {
+        quote = '\"';
+    }
+
+    /* The escaped string will be at most twice the length of the original. */
+    buff = (spif_charptr_t) MALLOC(strlen((char *) str) * 2 + 1);
+
+    /* Copy and escape the string from str into buff. */
+    for (pbuff = buff; (*s); s++, pbuff++) {
+        if (*s == quote) {
+            D_STRINGS(("Double-escaping \'%c\' at position %d\n", *s, s - str));
+            *pbuff = '\\';
+            pbuff++;
+            *pbuff = '\\';
+            pbuff++;
+        } else {
+            if (quote == '\"') {
+                if ((*s == '\\') || (*s == '`')) {
+                    D_STRINGS(("Escaping \'%c\' at position %d\n", *s, s - str));
+                    *pbuff = '\\';
+                    pbuff++;
+                }
+            }
+        }
+        D_STRINGS(("Copying \'%c\' at position %d\n", *s, s - str));
+        *pbuff = *s;
+    }
+    *pbuff = 0;
+
+    if (maxlen) {
+        /* Given maxlen, we know "str" can hold at least "maxlen" chars. */
+        if (!spiftool_safe_strncpy(str, buff, maxlen)) {
+            str[maxlen] = 0;
+        }
+        FREE(buff);
+        return str;
+    } else {
+        return buff;
+    }
+}
+
 char *
 safe_print_string(const char *str, unsigned long len)
 {
@@ -238,7 +285,7 @@ safe_print_string(const char *str, unsigned long len)
         rb_size = 0;
         return ((char *) NULL);
     }
-    if (ret_buff == NULL) {
+    if (!ret_buff) {
         rb_size = len;
         ret_buff = (char *) MALLOC(rb_size + 1);
     } else if (len > rb_size) {
@@ -269,7 +316,7 @@ add_carriage_returns(unsigned char *buff, unsigned long cnt)
     register unsigned char *out, *outp, *in;
     register unsigned long i;
 
-    D_CMD(("buff == %8p \"%s\", cnt == %lu\n", buff, safe_print_string(buff, cnt), cnt));
+    D_CMD(("buff == %8p \"%s\", cnt == %lu\n", buff, safe_print_string((spif_charptr_t) buff, cnt), cnt));
     outp = out = (unsigned char *) MALLOC(cnt * 2);
     for (i = 0, in = buff; i < cnt; i++) {
         if (*in == '\n') {
@@ -280,14 +327,14 @@ add_carriage_returns(unsigned char *buff, unsigned long cnt)
     i = (unsigned long) (out - outp);
     memcpy(buff, outp, i);
     FREE(outp);
-    D_CMD(("buff == %8p \"%s\", i == %lu\n", buff, safe_print_string(buff, i), i));
+    D_CMD(("buff == %8p \"%s\", i == %lu\n", buff, safe_print_string((spif_charptr_t) buff, i), i));
     return i;
 }
 
 unsigned char
 mkdirhier(const char *path)
 {
-    char *str, *pstr;
+    spif_charptr_t str, pstr;
     struct stat dst;
 
     D_CMD(("path == %s\n", path));
