@@ -46,15 +46,15 @@
 /* the following must use the char defined in NS_SCREEN_ESCAPE. if something
    else is used in the session, libscream will convert it on the fly. */
 /* DO NOT use \005Lw for your status, it breaks older screens!! */
-#define NS_SCREEN_UPDATE     "\x01w"
-#define NS_SCREEN_VERSION    "\x01v"
+#define NS_SCREEN_UPDATE     "\x01:windows\r"
+#define NS_SCREEN_VERSION    "\x01:version\r"
 #define NS_SCREEN_SESSION    "\x01:sessionname\r"
 #define NS_SCREEN_BELL       "\x01:bell_msg Wuff\r\x01:vbell_msg Wuff\r"
 #define NS_SCREEN_INIT       "\x01:msgminwait 0\r\x01:msgwait 0\r\x01:hardstatus on\r\x01:hardstatus alwayslastline \"%w\"\r\x01:defhstatus \"\\005w\"\r\x01:hstatus \"\\005w\"\r\x01:nethack off\r" NS_SCREEN_UPDATE "\r" NS_SCREEN_VERSION NS_SCREEN_SESSION "\x0c" NS_SCREEN_UPDATE "\r" NS_SCREEN_BELL
 #define NS_SCREEN_PRVS_REG   "\x01:focus up\r"
 
 #define NS_DFLT_SSH_PORT     22
-#define NS_MIN_PORT          1025
+#define NS_MIN_PORT          47323
 #define NS_MAX_PORT          65535
 
 #define NS_MAX_DISPS         512
@@ -68,12 +68,12 @@
 #define NS_SCREEN_ACT_T      "Activity in window "
 
 /* should be 1s */
-#define NS_INIT_DELAY        1
+#define NS_INIT_DELAY        2
 
 /* how many seconds to wait for an SSH-tunnel to build when using the
    -Z option (tunnel through firewall).  2 for very fast networks,
    much more for slow connections. */
-#define NS_TUNNEL_DELAY      3
+#define NS_TUNNEL_DELAY      30
 
 /* what to call the menu entry for Escreen */
 #define NS_MENU_TITLE        "Escreen"
