@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1997-2004, Michael Jennings
+ * Copyright (C) 1997-2009, Michael Jennings
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -21,7 +21,7 @@
  * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  */
 
-static const char cvs_ident[] = "$Id: startup.c,v 1.48 2004/11/07 20:38:20 mej Exp $";
+static const char cvs_ident[] = "$Id: startup.c 51650 2010-08-26 01:34:13Z lucas $";
 
 #include "config.h"
 #include "feature.h"
@@ -73,14 +73,14 @@ Atom props[NUM_PROPS];
 int
 eterm_bootstrap(int argc, char *argv[])
 {
-
     int i;
     char *val;
+
     /* "WINDOWID=\0" = 10 chars, UINT_MAX = 10 chars */
     static char windowid_string[20], *display_string, *term_string;
 
     orig_argv0 = argv[0];
-
+    
     /* Security enhancements -- mej */
     putenv("IFS= \t\n");
     my_ruid = getuid();
@@ -95,9 +95,7 @@ eterm_bootstrap(int argc, char *argv[])
     init_libast();
 
     /* Open display, get options/resources and create the window */
-    if (getenv("DISPLAY") == NULL) {
-        display_name = STRDUP(":0");
-    } else {
+    if (getenv("DISPLAY")) {
         display_name = STRDUP(getenv("DISPLAY"));
     }
 
@@ -115,8 +113,10 @@ eterm_bootstrap(int argc, char *argv[])
 #ifdef NEED_LINUX_HACK
     privileges(REVERT);
 #endif
-    if (!Xdisplay) {
-        print_error("can't open display %s\n", display_name);
+
+    if (!Xdisplay && !(Xdisplay = XOpenDisplay(display_name))) {
+        libast_print_error("Can't open display %s.  Set $DISPLAY or use --display\n",
+                           NONULL(display_name));
         exit(EXIT_FAILURE);
     }
     XSetErrorHandler((XErrorHandler) xerror_handler);
@@ -138,6 +138,10 @@ eterm_bootstrap(int argc, char *argv[])
 
     /* Get all our properties set up. */
     MEMSET(props, 0, sizeof(props));
+    props[PROP_TEXT] = XInternAtom(Xdisplay, "TEXT", False);
+    props[PROP_COMPOUND_TEXT] = XInternAtom(Xdisplay, "COMPOUND_TEXT", False);
+    props[PROP_UTF8_STRING] = XInternAtom(Xdisplay, "UTF8_STRING", False);
+    props[PROP_CLIPBOARD] = XInternAtom(Xdisplay, "CLIPBOARD", False);
     props[PROP_DESKTOP] = XInternAtom(Xdisplay, "_NET_WM_DESKTOP", False);
     props[PROP_TRANS_PIXMAP] = XInternAtom(Xdisplay, "_XROOTPMAP_ID", False);
     props[PROP_TRANS_COLOR] = XInternAtom(Xdisplay, "_XROOTCOLOR_PIXEL", False);
@@ -145,24 +149,29 @@ eterm_bootstrap(int argc, char *argv[])
     props[PROP_SELECTION_INCR] = XInternAtom(Xdisplay, "INCR", False);
     props[PROP_SELECTION_TARGETS] = XInternAtom(Xdisplay, "TARGETS", False);
     props[PROP_ENL_COMMS] = XInternAtom(Xdisplay, "ENLIGHTENMENT_COMMS", True);
+    props[PROP_ENL_VERSION] = XInternAtom(Xdisplay, "ENLIGHTENMENT_VERSION", True);
     props[PROP_ENL_MSG] = XInternAtom(Xdisplay, "ENL_MSG", False);
     props[PROP_DELETE_WINDOW] = XInternAtom(Xdisplay, "WM_DELETE_WINDOW", False);
     props[PROP_DND_PROTOCOL] = XInternAtom(Xdisplay, "DndProtocol", False);
     props[PROP_DND_SELECTION] = XInternAtom(Xdisplay, "DndSelection", False);
     props[PROP_EWMH_ICON] = XInternAtom(Xdisplay, "_NET_WM_ICON", False);
+    props[PROP_EWMH_OPACITY] = XInternAtom(Xdisplay, "_NET_WM_WINDOW_OPACITY", True);
+    props[PROP_EWMH_STARTUP_ID] = XInternAtom(Xdisplay, "_NET_STARTUP_ID", False);
+    props[PROP_EWMH_STATE] = XInternAtom(Xdisplay, "_NET_WM_STATE", False);
+    props[PROP_EWMH_STATE_STICKY] = XInternAtom(Xdisplay, "_NET_WM_STATE_STICKY", False);
 
-    if ((theme_dir = conf_parse_theme(&rs_theme, THEME_CFG, PARSE_TRY_ALL)) != NULL) {
+    if ((theme_dir = spifconf_parse_theme(&rs_theme, THEME_CFG, PARSE_TRY_ALL))) {
         char *tmp;
 
-        D_OPTIONS(("conf_parse_theme() returned \"%s\"\n", theme_dir));
+        D_OPTIONS(("spifconf_parse_theme() returned \"%s\"\n", theme_dir));
         tmp = (char *) MALLOC(strlen(theme_dir) + sizeof("ETERM_THEME_ROOT=\0"));
         sprintf(tmp, "ETERM_THEME_ROOT=%s", theme_dir);
         putenv(tmp);
     }
-    if ((user_dir = conf_parse_theme(&rs_theme, (rs_config_file ? rs_config_file : USER_CFG), (PARSE_TRY_USER_THEME | PARSE_TRY_NO_THEME))) != NULL) {
+    if ((user_dir = spifconf_parse_theme(&rs_theme, (rs_config_file ? rs_config_file : USER_CFG), (PARSE_TRY_USER_THEME | PARSE_TRY_NO_THEME)))) {
         char *tmp;
 
-        D_OPTIONS(("conf_parse_theme() returned \"%s\"\n", user_dir));
+        D_OPTIONS(("spifconf_parse_theme() returned \"%s\"\n", user_dir));
         tmp = (char *) MALLOC(strlen(user_dir) + sizeof("ETERM_USER_ROOT=\0"));
         sprintf(tmp, "ETERM_USER_ROOT=%s", user_dir);
         putenv(tmp);
@@ -193,7 +202,8 @@ eterm_bootstrap(int argc, char *argv[])
 #endif
     spifopt_parse(argc, argv);
     D_UTMP(("Saved real uid/gid = [ %d, %d ]  effective uid/gid = [ %d, %d ]\n", my_ruid, my_rgid, my_euid, my_egid));
-    D_UTMP(("Now running with real uid/gid = [ %d, %d ]  effective uid/gid = [ %d, %d ]\n", getuid(), getgid(), geteuid(), getegid()));
+    D_UTMP(("Now running with real uid/gid = [ %d, %d ]  effective uid/gid = [ %d, %d ]\n", getuid(), getgid(), geteuid(),
+            getegid()));
 
 #ifdef ESCREEN
 #  define ESCREEN_PREFIX "Escreen"
@@ -239,7 +249,8 @@ eterm_bootstrap(int argc, char *argv[])
 
     /* Initialize the scrollbar */
     scrollbar_init(szHint.width, szHint.height - bbar_calc_docked_height(BBAR_DOCKED));
-    scrollbar_mapping((BITFIELD_IS_SET(eterm_options, ETERM_OPTIONS_SCROLLBAR)) && !((BITFIELD_IS_SET(eterm_options, ETERM_OPTIONS_SCROLLBAR_POPUP)) && !TermWin.focus));
+    scrollbar_mapping((BITFIELD_IS_SET(eterm_options, ETERM_OPTIONS_SCROLLBAR))
+                      && !((BITFIELD_IS_SET(eterm_options, ETERM_OPTIONS_SCROLLBAR_POPUP)) && !TermWin.focus));
 
     /* Initialize the menu subsystem. */
     menu_init();
@@ -254,24 +265,10 @@ eterm_bootstrap(int argc, char *argv[])
     }
 #endif
 
-#ifdef DISPLAY_IS_IP
-    /* Fixup display_name for export over pty to any interested terminal
-     * clients via "ESC[7n" (e.g. shells).  Note we use the pure IP number
-     * (for the first non-loopback interface) that we get from
-     * network_display().  This is more "name-resolution-portable", if you
-     * will, and probably allows for faster x-client startup if your name
-     * server is beyond a slow link or overloaded at client startup.  Of
-     * course that only helps the shell's child processes, not us.
-     *
-     * Giving out the display_name also affords a potential security hole
-     */
-
-    val = display_name = network_display(display_name);
-    if (val == NULL)
-#endif /* DISPLAY_IS_IP */
-        val = XDisplayString(Xdisplay);
-    if (display_name == NULL)
-        display_name = val;     /* use broken `:0' value */
+    val = XDisplayString(Xdisplay);
+    if (!display_name) {
+        display_name = val;
+    }
 
     i = strlen(val);
     display_string = MALLOC(i + 9);
@@ -293,7 +290,7 @@ eterm_bootstrap(int argc, char *argv[])
         putenv("COLORTERM_BCE=" COLORTERMENV "-mono");
         putenv("TERM=" TERMENV);
     } else {
-        if (rs_term_name != NULL) {
+        if (rs_term_name) {
             i = strlen(rs_term_name);
             term_string = MALLOC(i + 6);
 
@@ -317,12 +314,14 @@ eterm_bootstrap(int argc, char *argv[])
 #ifdef NO_UTF8_LOCALE
     /* Check locale for UTF-8 and deactivate if needed. */
     val = getenv("LANG");
+    D_CMD(("Checking locale \"%s\" for UTF-8.\n", NONULL(val)));
     if (val && *val) {
         char *tmp;
 
         tmp = strcasestr(val, ".utf");
         if (tmp) {
             *tmp = 0;
+            D_CMD((" -> Deactivating unsupported UTF-8 locale; now using \"%s\"\n", val));
         }
     }
 #endif
