@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1997-2004, Michael Jennings
+ * Copyright (C) 1997-2009, Michael Jennings
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -91,6 +91,10 @@
 #endif
 
 enum {
+  PROP_TEXT,
+  PROP_COMPOUND_TEXT,
+  PROP_UTF8_STRING,
+  PROP_CLIPBOARD,
   PROP_DESKTOP,
   PROP_TRANS_PIXMAP,
   PROP_TRANS_COLOR,
@@ -98,11 +102,16 @@ enum {
   PROP_SELECTION_INCR,
   PROP_SELECTION_TARGETS,
   PROP_ENL_COMMS,
+  PROP_ENL_VERSION,
   PROP_ENL_MSG,
   PROP_DELETE_WINDOW,
   PROP_DND_PROTOCOL,
   PROP_DND_SELECTION,
   PROP_EWMH_ICON,
+  PROP_EWMH_OPACITY,
+  PROP_EWMH_STARTUP_ID,
+  PROP_EWMH_STATE,
+  PROP_EWMH_STATE_STICKY,
   NUM_PROPS
 };
 
