@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1997-2004, Michael Jennings
+ * Copyright (C) 1997-2009, Michael Jennings
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -21,7 +21,7 @@
  * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  */
 
-static const char cvs_ident[] = "$Id: system.c,v 1.21 2004/01/11 22:10:29 mej Exp $";
+static const char cvs_ident[] = "$Id: system.c 38480 2009-01-06 09:08:48Z mej $";
 
 #include "../config.h"
 #include "feature.h"
@@ -52,6 +52,7 @@ wait_for_chld(int system_pid)
     while (1) {
         do {
             errno = 0;
+            usleep(10);
         } while ((((pid = waitpid(system_pid, &status, WNOHANG)) == -1) && (errno == EINTR)) || !pid);
         /* If the child that exited is the command we spawned, or if the
            child exited before fork() returned in the parent, it must be
@@ -79,32 +80,20 @@ wait_for_chld(int system_pid)
 }
 
 /* Replace the system() call with a fork-and-exec that unprivs the child process */
-
 int
 system_wait(char *command)
 {
-
     pid_t pid;
 
     D_OPTIONS(("system_wait(%s) called.\n", command));
 
-    if (!(pid = fork())) {
-        setreuid(my_ruid, my_ruid);
-        setregid(my_rgid, my_rgid);
-        execl("/bin/sh", "sh", "-c", command, (char *) NULL);
-        print_error("execl(%s) failed -- %s\n", command, strerror(errno));
-        exit(EXIT_FAILURE);
-    } else {
-        D_OPTIONS(("%d:  fork() returned %d\n", getpid(), pid));
-        return (wait_for_chld(pid));
-    }
-    ASSERT_NOTREACHED_RVAL(0);
+    pid = system_no_wait(command);
+    return (wait_for_chld(pid));
 }
 
-int
+pid_t
 system_no_wait(char *command)
 {
-
     pid_t pid;
 
     D_OPTIONS(("system_no_wait(%s) called.\n", command));
@@ -113,8 +102,9 @@ system_no_wait(char *command)
         setreuid(my_ruid, my_ruid);
         setregid(my_rgid, my_rgid);
         execl("/bin/sh", "sh", "-c", command, (char *) NULL);
-        print_error("execl(%s) failed -- %s\n", command, strerror(errno));
+        libast_print_error("execl(%s) failed -- %s\n", command, strerror(errno));
         exit(EXIT_FAILURE);
     }
-    return (0);
+    D_OPTIONS(("%d:  fork() returned %d\n", getpid(), pid));
+    return (pid);
 }
