@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1997-2004, Michael Jennings
+ * Copyright (C) 1997-2009, Michael Jennings
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -21,7 +21,7 @@
  * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  */
 
-static const char cvs_ident[] = "$Id: timer.c,v 1.14 2004/01/11 22:10:29 mej Exp $";
+static const char cvs_ident[] = "$Id: timer.c 38480 2009-01-06 09:08:48Z mej $";
 
 #include "config.h"
 #include "feature.h"
@@ -61,7 +61,8 @@ timer_add(unsigned long msec, timer_handler_t handler, void *data)
     timer->time.tv_usec = ((msec % 1000) * 1000) + tv.tv_usec;
     timer->handler = handler;
     timer->data = data;
-    D_TIMER(("Added timer.  Timer set to %lu/%lu with handler %8p and data %8p\n", timer->time.tv_sec, timer->time.tv_usec, timer->handler, timer->data));
+    D_TIMER(("Added timer.  Timer set to %lu/%lu with handler %8p and data %8p\n", timer->time.tv_sec, timer->time.tv_usec,
+             timer->handler, timer->data));
     return ((timerhdl_t) timer);
 }
 
