@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1997-2004, Michael Jennings
+ * Copyright (C) 1997-2009, Michael Jennings
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -21,7 +21,7 @@
  * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  */
 
-static const char cvs_ident[] = "$Id: windows.c,v 1.67 2004/06/25 21:52:00 mej Exp $";
+static const char cvs_ident[] = "$Id: windows.c 51650 2010-08-26 01:34:13Z lucas $";
 
 #include "config.h"
 #include "feature.h"
@@ -69,7 +69,7 @@ set_text_property(Window win, char *propname, char *value)
 
     ASSERT(propname != NULL);
 
-    if (value == NULL) {
+    if (!value) {
         atom = XInternAtom(Xdisplay, propname, True);
         if (atom == None) {
             return;
@@ -96,7 +96,7 @@ get_tint_by_color_name(const char *color)
 
     D_PIXMAP(("Tint string is \"%s\", white color is rgbi:%d/%d/%d\n", color, wcol.red, wcol.green, wcol.blue));
     if (!XParseColor(Xdisplay, cmap, color, &xcol)) {
-        print_error("Unable to parse tint color \"%s\".  Ignoring.\n", color);
+        libast_print_error("Unable to parse tint color \"%s\".  Ignoring.\n", color);
         return 0xffffff;
     }
 
@@ -144,7 +144,8 @@ get_bottom_shadow_color(Pixel norm_color, const char *type)
     xcol.blue /= 2;
 
     if (!XAllocColor(Xdisplay, cmap, &xcol)) {
-        print_error("Unable to allocate \"%s\" (0x%08x:  0x%04x, 0x%04x, 0x%04x) in the color map.\n", type, xcol.pixel, xcol.red, xcol.green, xcol.blue);
+        libast_print_error("Unable to allocate \"%s\" (0x%08x:  0x%04x, 0x%04x, 0x%04x) in the color map.\n", type, xcol.pixel, xcol.red,
+                    xcol.green, xcol.blue);
         xcol.pixel = PixColors[minColor];
     }
     return (xcol.pixel);
@@ -176,7 +177,8 @@ get_top_shadow_color(Pixel norm_color, const char *type)
     xcol.blue = MIN(white.blue, (xcol.blue * 7) / 5);
 
     if (!XAllocColor(Xdisplay, cmap, &xcol)) {
-        print_error("Unable to allocate \"%s\" (0x%08x:  0x%04x, 0x%04x, 0x%04x) in the color map.\n", type, xcol.pixel, xcol.red, xcol.green, xcol.blue);
+        libast_print_error("Unable to allocate \"%s\" (0x%08x:  0x%04x, 0x%04x, 0x%04x) in the color map.\n", type, xcol.pixel, xcol.red,
+                    xcol.green, xcol.blue);
         xcol.pixel = PixColors[WhiteColor];
     }
     return (xcol.pixel);
@@ -187,8 +189,8 @@ get_color_by_name(const char *name, const char *fallback)
 {
     XColor xcol;
 
-    if (name == NULL) {
-        if (fallback == NULL) {
+    if (!name) {
+        if (!fallback) {
             return ((Pixel) - 1);
         } else {
             name = fallback;
@@ -202,11 +204,13 @@ get_color_by_name(const char *name, const char *fallback)
         }
     }
     if (!XParseColor(Xdisplay, cmap, name, &xcol)) {
-        print_warning("Unable to resolve \"%s\" as a color name.  Falling back on \"%s\".\n", name, NONULL(fallback));
+        libast_print_warning("Unable to resolve \"%s\" as a color name.  Falling back on \"%s\".\n", name, NONULL(fallback));
         name = fallback;
         if (name) {
             if (!XParseColor(Xdisplay, cmap, name, &xcol)) {
-                print_warning("Unable to resolve \"%s\" as a color name.  This should never fail.  Please repair/restore your RGB database.\n", name);
+                libast_print_warning
+                    ("Unable to resolve \"%s\" as a color name.  This should never fail.  Please repair/restore your RGB database.\n",
+                     name);
                 return ((Pixel) - 1);
             }
         } else {
@@ -214,12 +218,13 @@ get_color_by_name(const char *name, const char *fallback)
         }
     }
     if (!XAllocColor(Xdisplay, cmap, &xcol)) {
-        print_warning("Unable to allocate \"%s\" (0x%08x:  0x%04x, 0x%04x, 0x%04x) in the color map.  Falling back on \"%s\".\n",
+        libast_print_warning("Unable to allocate \"%s\" (0x%08x:  0x%04x, 0x%04x, 0x%04x) in the color map.  Falling back on \"%s\".\n",
                       name, xcol.pixel, xcol.red, xcol.green, xcol.blue, NONULL(fallback));
         name = fallback;
         if (name) {
             if (!XAllocColor(Xdisplay, cmap, &xcol)) {
-                print_warning("Unable to allocate \"%s\" (0x%08x:  0x%04x, 0x%04x, 0x%04x) in the color map.\n", name, xcol.pixel, xcol.red, xcol.green, xcol.blue);
+                libast_print_warning("Unable to allocate \"%s\" (0x%08x:  0x%04x, 0x%04x, 0x%04x) in the color map.\n", name, xcol.pixel,
+                              xcol.red, xcol.green, xcol.blue);
                 return ((Pixel) - 1);
             }
         } else {
@@ -236,18 +241,20 @@ get_color_by_pixel(Pixel pixel, Pixel fallback)
 
     xcol.pixel = pixel;
     if (!XQueryColor(Xdisplay, cmap, &xcol)) {
-        print_warning("Unable to convert pixel value 0x%08x to an XColor structure.  Falling back on 0x%08x.\n", pixel, fallback);
+        libast_print_warning("Unable to convert pixel value 0x%08x to an XColor structure.  Falling back on 0x%08x.\n", pixel, fallback);
         xcol.pixel = fallback;
         if (!XQueryColor(Xdisplay, cmap, &xcol)) {
-            print_warning("Unable to convert pixel value 0x%08x to an XColor structure.\n", xcol.pixel);
+            libast_print_warning("Unable to convert pixel value 0x%08x to an XColor structure.\n", xcol.pixel);
             return ((Pixel) 0);
         }
     }
     if (!XAllocColor(Xdisplay, cmap, &xcol)) {
-        print_warning("Unable to allocate 0x%08x (0x%04x, 0x%04x, 0x%04x) in the color map.  Falling back on 0x%08x.\n", xcol.pixel, xcol.red, xcol.green, xcol.blue, fallback);
+        libast_print_warning("Unable to allocate 0x%08x (0x%04x, 0x%04x, 0x%04x) in the color map.  Falling back on 0x%08x.\n", xcol.pixel,
+                      xcol.red, xcol.green, xcol.blue, fallback);
         xcol.pixel = fallback;
         if (!XAllocColor(Xdisplay, cmap, &xcol)) {
-            print_warning("Unable to allocate 0x%08x (0x%04x, 0x%04x, 0x%04x) in the color map.\n", xcol.pixel, xcol.red, xcol.green, xcol.blue);
+            libast_print_warning("Unable to allocate 0x%08x (0x%04x, 0x%04x, 0x%04x) in the color map.\n", xcol.pixel, xcol.red,
+                          xcol.green, xcol.blue);
             return ((Pixel) 0);
         }
     }
@@ -261,49 +268,51 @@ process_colors(void)
     Pixel pixel;
 
     for (i = 0; i < NRS_COLORS; i++) {
+        D_COLORS(("Adding color %d of %d (%s)\n", i, NRS_COLORS, def_colorName[i]));
         if ((Xdepth <= 2) || ((pixel = get_color_by_name(rs_color[i], def_colorName[i])) == (Pixel) (-1))) {
             switch (i) {
-              case fgColor:
-                  pixel = WhitePixel(Xdisplay, Xscreen);
-                  break;
-              case bgColor:
-                  pixel = BlackPixel(Xdisplay, Xscreen);
-                  break;
+                case fgColor:
+                    pixel = WhitePixel(Xdisplay, Xscreen);
+                    break;
+                case bgColor:
+                    pixel = BlackPixel(Xdisplay, Xscreen);
+                    break;
 #ifndef NO_CURSORCOLOR
-              case cursorColor:
-                  pixel = PixColors[bgColor];
-                  break;
-              case cursorColor2:
-                  pixel = PixColors[fgColor];
-                  break;
+                case cursorColor:
+                    pixel = PixColors[bgColor];
+                    break;
+                case cursorColor2:
+                    pixel = PixColors[fgColor];
+                    break;
 #endif /* NO_CURSORCOLOR */
 #ifndef NO_BOLDUNDERLINE
-              case colorBD:
-                  pixel = PixColors[fgColor];
-                  break;
-              case colorUL:
-                  pixel = PixColors[fgColor];
-                  break;
+                case colorBD:
+                    pixel = PixColors[fgColor];
+                    break;
+                case colorUL:
+                    pixel = PixColors[fgColor];
+                    break;
 #endif
 #ifdef ESCREEN
-              case ES_COLOR_CURRENT:
-                  pixel = PixColors[YellowColor];
-                  break;
-              case ES_COLOR_ACTIVE:
-                  pixel = PixColors[BlueColor];
-                  break;
+                case ES_COLOR_CURRENT:
+                    pixel = PixColors[YellowColor];
+                    break;
+                case ES_COLOR_ACTIVE:
+                    pixel = PixColors[BlueColor];
+                    break;
 #endif
-              case pointerColor:
-                  pixel = PixColors[fgColor];
-                  break;
-              case borderColor:
-                  pixel = PixColors[bgColor];
-                  break;
-              default:
-                  pixel = PixColors[fgColor];   /* None */
-                  break;
+                case pointerColor:
+                    pixel = PixColors[fgColor];
+                    break;
+                case borderColor:
+                    pixel = PixColors[bgColor];
+                    break;
+                default:
+                    pixel = PixColors[fgColor]; /* None */
+                    break;
             }
         }
+        D_COLORS(("Pixel : %x\n", pixel));
         PixColors[i] = pixel;
     }
 
@@ -319,14 +328,17 @@ process_colors(void)
         PixColors[unfocusedMenuBottomShadowColor] = PixColors[fgColor];
     } else {
         PixColors[bottomShadowColor] = get_bottom_shadow_color(images[image_sb].norm->bg, "bottomShadowColor");
-        PixColors[unfocusedBottomShadowColor] = get_bottom_shadow_color(images[image_sb].disabled->bg, "unfocusedBottomShadowColor");
+        PixColors[unfocusedBottomShadowColor] =
+            get_bottom_shadow_color(images[image_sb].disabled->bg, "unfocusedBottomShadowColor");
         PixColors[topShadowColor] = get_top_shadow_color(images[image_sb].norm->bg, "topShadowColor");
         PixColors[unfocusedTopShadowColor] = get_top_shadow_color(images[image_sb].disabled->bg, "unfocusedTopShadowColor");
 
         PixColors[menuBottomShadowColor] = get_bottom_shadow_color(images[image_menu].norm->bg, "menuBottomShadowColor");
-        PixColors[unfocusedMenuBottomShadowColor] = get_bottom_shadow_color(images[image_menu].disabled->bg, "unfocusedMenuBottomShadowColor");
+        PixColors[unfocusedMenuBottomShadowColor] =
+            get_bottom_shadow_color(images[image_menu].disabled->bg, "unfocusedMenuBottomShadowColor");
         PixColors[menuTopShadowColor] = get_top_shadow_color(images[image_menu].norm->bg, "menuTopShadowColor");
-        PixColors[unfocusedMenuTopShadowColor] = get_top_shadow_color(images[image_menu].disabled->bg, "unfocusedMenuTopShadowColor");
+        PixColors[unfocusedMenuTopShadowColor] =
+            get_top_shadow_color(images[image_menu].disabled->bg, "unfocusedMenuTopShadowColor");
     }
     stored_palette(SAVE);
 }
@@ -336,13 +348,13 @@ set_pointer_colors(const char *fg_name, const char *bg_name)
 {
     XColor fg, bg;
 
-    if (fg_name != NULL) {
+    if (fg_name) {
         fg.pixel = get_color_by_name(fg_name, COLOR_NAME(pointerColor));
     } else {
         fg.pixel = PixColors[pointerColor];
     }
     XQueryColor(Xdisplay, cmap, &fg);
-    if (bg_name != NULL) {
+    if (bg_name) {
         bg.pixel = get_color_by_name(bg_name, COLOR_NAME(bgColor));
     } else {
         bg.pixel = PixColors[bgColor];
@@ -366,21 +378,15 @@ Create_Windows(int argc, char *argv[])
     MWMHints mwmhints;
 
     if (BITFIELD_IS_SET(eterm_options, ETERM_OPTIONS_BORDERLESS)) {
-        prop = XInternAtom(Xdisplay, "_MOTIF_WM_INFO", True);
-        if (prop == None) {
-            print_warning("Window Manager does not support MWM hints.  Bypassing window manager control for borderless window.\n");
-            Attributes.override_redirect = TRUE;
-            mwmhints.flags = 0;
-        } else {
-            mwmhints.flags = MWM_HINTS_DECORATIONS;
-            mwmhints.decorations = 0;
-        }
+        mwmhints.flags = MWM_HINTS_DECORATIONS;
+        mwmhints.decorations = 0;
     } else {
         mwmhints.flags = 0;
     }
     Attributes.colormap = cmap;
 
-    szHint.base_width = (2 * TermWin.internalBorder + ((BITFIELD_IS_SET(eterm_options, ETERM_OPTIONS_SCROLLBAR)) ? (scrollbar_get_width() + (2 * scrollbar_get_shadow())) : 0));
+    szHint.base_width = (2 * TermWin.internalBorder + ((BITFIELD_IS_SET(eterm_options, ETERM_OPTIONS_SCROLLBAR))
+                                                       ? (scrollbar_get_width() + (2 * scrollbar_get_shadow())) : 0));
     szHint.base_height = (2 * TermWin.internalBorder) + bbar_calc_docked_height(BBAR_DOCKED);
 
     flags = (rs_geometry ? XParseGeometry(rs_geometry, &x, &y, &width, &height) : 0);
@@ -420,7 +426,8 @@ Create_Windows(int argc, char *argv[])
     Attributes.background_pixel = PixColors[bgColor];
     Attributes.border_pixel = PixColors[bgColor];
     D_X11(("Size Hints:  x %d, y %d.  Width/Height:  Base %dx%d, Minimum %dx%d, Current %dx%d, Increment %dx%d\n",
-           szHint.x, szHint.y, szHint.base_width, szHint.base_height, szHint.min_width, szHint.min_height, szHint.width, szHint.height, szHint.width_inc, szHint.height_inc));
+           szHint.x, szHint.y, szHint.base_width, szHint.base_height, szHint.min_width, szHint.min_height, szHint.width,
+           szHint.height, szHint.width_inc, szHint.height_inc));
     TermWin.parent = XCreateWindow(Xdisplay, Xroot, szHint.x, szHint.y, szHint.width, szHint.height, 0, Xdepth, InputOutput,
 #ifdef PREFER_24BIT
                                    Xvisual,
@@ -444,11 +451,14 @@ Create_Windows(int argc, char *argv[])
 
     XSetWMProperties(Xdisplay, TermWin.parent, NULL, NULL, argv, argc, &szHint, &wmHint, &classHint);
     XSelectInput(Xdisplay, Xroot, PropertyChangeMask);
-    XSelectInput(Xdisplay, TermWin.parent, (KeyPressMask | FocusChangeMask | StructureNotifyMask | VisibilityChangeMask | PropertyChangeMask));
+    XSelectInput(Xdisplay, TermWin.parent,
+                 (KeyPressMask | FocusChangeMask | StructureNotifyMask | VisibilityChangeMask | PropertyChangeMask));
     if (mwmhints.flags) {
         prop = XInternAtom(Xdisplay, "_MOTIF_WM_HINTS", False);
-        XChangeProperty(Xdisplay, TermWin.parent, prop, prop, 32, PropModeReplace, (unsigned char *) &mwmhints, PROP_MWM_HINTS_ELEMENTS);
+        XChangeProperty(Xdisplay, TermWin.parent, prop, prop, 32,
+                        PropModeReplace, (unsigned char *) &mwmhints, PROP_MWM_HINTS_ELEMENTS);
     }
+
     /* vt cursor: Black-on-White is standard, but this is more popular */
     TermWin_cursor = XCreateFontCursor(Xdisplay, XC_xterm);
     set_pointer_colors(NULL, NULL);
@@ -457,9 +467,12 @@ Create_Windows(int argc, char *argv[])
     cursor = XCreateFontCursor(Xdisplay, XC_left_ptr);
 
     /* the vt window */
-    TermWin.x = (((BITFIELD_IS_SET(eterm_options, ETERM_OPTIONS_SCROLLBAR)) && !(BITFIELD_IS_SET(eterm_options, ETERM_OPTIONS_SCROLLBAR_RIGHT))) ? (scrollbar_get_width() + (2 * scrollbar_get_shadow())) : 0);
+    TermWin.x = (((BITFIELD_IS_SET(eterm_options, ETERM_OPTIONS_SCROLLBAR))
+                  && !(BITFIELD_IS_SET(eterm_options, ETERM_OPTIONS_SCROLLBAR_RIGHT)))
+                 ? (scrollbar_get_width() + (2 * scrollbar_get_shadow())) : 0);
     TermWin.y = bbar_calc_docked_height(BBAR_DOCKED_TOP);
-    TermWin.vt = XCreateWindow(Xdisplay, TermWin.parent, TermWin.x, TermWin.y, szHint.width, szHint.height, 0, Xdepth, InputOutput, CopyFromParent,
+    TermWin.vt = XCreateWindow(Xdisplay, TermWin.parent, TermWin.x, TermWin.y, szHint.width, szHint.height,
+                               0, Xdepth, InputOutput, CopyFromParent,
                                CWBackPixel | CWBorderPixel | CWOverrideRedirect | CWColormap, &Attributes);
     D_X11(("Created terminal window 0x%08x at %dx%d\n", TermWin.vt, TermWin.x, TermWin.y));
     if (!(background_is_pixmap()) && !(BITFIELD_IS_SET(eterm_options, ETERM_OPTIONS_BORDERLESS))) {
@@ -467,9 +480,9 @@ Create_Windows(int argc, char *argv[])
         XClearWindow(Xdisplay, TermWin.vt);
     }
     XDefineCursor(Xdisplay, TermWin.vt, TermWin_cursor);
-    TermWin.mask = (KeyPressMask | EnterWindowMask | LeaveWindowMask | ExposureMask
-                    | ButtonPressMask | ButtonReleaseMask | Button1MotionMask
-                    | Button2MotionMask | Button3MotionMask);
+    TermWin.mask =
+        (EnterWindowMask | LeaveWindowMask | ExposureMask | ButtonPressMask | ButtonReleaseMask | Button1MotionMask |
+         Button2MotionMask | Button3MotionMask);
     XSelectInput(Xdisplay, TermWin.vt, TermWin.mask);
 
     /* If the user wants a specific desktop, tell the WM that */
@@ -478,6 +491,30 @@ Create_Windows(int argc, char *argv[])
         XChangeProperty(Xdisplay, TermWin.parent, props[PROP_DESKTOP], XA_CARDINAL, 32, PropModeReplace, (unsigned char *) &val, 1);
     }
 
+    /* Make window sticky if requested */
+    if (BITFIELD_IS_SET(eterm_options, ETERM_OPTIONS_STICKY)) {
+        XChangeProperty(Xdisplay, TermWin.parent, props[PROP_EWMH_STATE], XA_ATOM, 32, PropModeReplace,
+                        (unsigned char *) &props[PROP_EWMH_STATE_STICKY], 1);
+    }
+
+    /* Set startup ID property if given by the launching application. */
+    if (getenv("DESKTOP_STARTUP_ID")) {
+        Atom atom;
+        unsigned char *tmp = (spif_uchar_t *) getenv("DESKTOP_STARTUP_ID");
+
+        atom = XInternAtom(Xdisplay, "UTF8_STRING", False);
+        XChangeProperty(Xdisplay, TermWin.parent, props[PROP_EWMH_STARTUP_ID], atom, 8, PropModeReplace, tmp, strlen(tmp) + 1);
+        unsetenv("DESKTOP_STARTUP_ID");
+    }
+
+    /* Set window opacity if needed. */
+    if ((props[PROP_EWMH_OPACITY] != None) && (rs_opacity != 0xff)) {
+        XChangeProperty(Xdisplay, TermWin.parent, props[PROP_EWMH_OPACITY],
+                        XA_CARDINAL, 32, PropModeReplace, (spif_uchar_t *) &rs_opacity, 1);
+        XChangeProperty(Xdisplay, TermWin.vt, props[PROP_EWMH_OPACITY],
+                        XA_CARDINAL, 32, PropModeReplace, (spif_uchar_t *) &rs_opacity, 1);
+    }
+
     /* We're done creating our windows.  Now let's initialize the event subsystem to handle them. */
     event_init_subsystem((event_dispatcher_t) process_x_event, (event_dispatcher_init_t) event_init_primary_dispatcher);
 
@@ -499,6 +536,7 @@ Create_Windows(int argc, char *argv[])
         gcvalue.background = PixColors[bgColor];
         gcvalue.graphics_exposures = 0;
         TermWin.gc = LIBAST_X_CREATE_GC(GCForeground | GCBackground | GCFont | GCGraphicsExposures, &gcvalue);
+        D_X11(("Created GC 0x%08x for TermWin.gc\n", TermWin.gc));
     }
 
     if (BITFIELD_IS_SET(eterm_options, ETERM_OPTIONS_NO_CURSOR)) {
@@ -539,7 +577,8 @@ resize_parent(unsigned int width, unsigned int height)
             /* exact center */
             dy /= 2;
         }
-        D_X11(("Calling XMoveResizeWindow(Xdisplay, 0x%08x, %d + %d, %d + %d, %d, %d)\n", TermWin.parent, x, dx, y, dy, width, height));
+        D_X11(("Calling XMoveResizeWindow(Xdisplay, 0x%08x, %d + %d, %d + %d, %d, %d)\n", TermWin.parent, x, dx, y, dy, width,
+               height));
         XMoveResizeWindow(Xdisplay, TermWin.parent, x + dx, y + dy, width, height);
     }
 }
@@ -563,19 +602,21 @@ void
 update_size_hints(void)
 {
     D_X11(("Called.\n"));
-    szHint.base_width = (2 * TermWin.internalBorder) + ((scrollbar_is_visible()) ? (scrollbar_trough_width()) : (0));
+    szHint.base_width = (2 * TermWin.internalBorder) + ((scrollbar_is_visible())? (scrollbar_trough_width()) : (0));
     szHint.base_height = (2 * TermWin.internalBorder) + bbar_calc_docked_height(BBAR_DOCKED);
 
     szHint.width_inc = TermWin.fwidth;
     szHint.height_inc = TermWin.fheight;
 
-    D_X11(("Size Hints:  base width/height == %lux%lu, width/height increment == %lux%lu\n", szHint.base_width, szHint.base_height, szHint.width_inc, szHint.height_inc));
+    D_X11(("Size Hints:  base width/height == %lux%lu, width/height increment == %lux%lu\n", szHint.base_width, szHint.base_height,
+           szHint.width_inc, szHint.height_inc));
 
     szHint.min_width = szHint.base_width + szHint.width_inc;
     szHint.min_height = szHint.base_height + szHint.height_inc;
     szHint.width = szHint.base_width + TERM_WINDOW_GET_WIDTH();
     szHint.height = szHint.base_height + TERM_WINDOW_GET_HEIGHT();
-    D_X11(("             Minimum width/height == %lux%lu, width/height == %lux%lu\n", szHint.min_width, szHint.min_height, szHint.width, szHint.height));
+    D_X11(("             Minimum width/height == %lux%lu, width/height == %lux%lu\n", szHint.min_width, szHint.min_height,
+           szHint.width, szHint.height));
 
     szHint.flags = PMinSize | PResizeInc | PBaseSize;
     XSetWMNormalHints(Xdisplay, TermWin.parent, &szHint);
@@ -593,8 +634,8 @@ term_resize(int width, int height)
     D_X11((" -> New TermWin width/height == %lux%lu\n", TERM_WINDOW_GET_WIDTH(), TERM_WINDOW_GET_HEIGHT()));
     width = TERM_WINDOW_FULL_WIDTH();
     height = TERM_WINDOW_FULL_HEIGHT();
-    XMoveResizeWindow(Xdisplay, TermWin.vt,
-                      ((BITFIELD_IS_SET(eterm_options, ETERM_OPTIONS_SCROLLBAR_RIGHT)) ? (0) : ((scrollbar_is_visible())? (scrollbar_trough_width()) : (0))),
+    XMoveResizeWindow(Xdisplay, TermWin.vt, ((BITFIELD_IS_SET(eterm_options, ETERM_OPTIONS_SCROLLBAR_RIGHT)) ? (0)
+                                             : ((scrollbar_is_visible())? (scrollbar_trough_width()) : (0))),
                       bbar_calc_docked_height(BBAR_DOCKED_TOP), width, height);
     if (width != last_width || height != last_height) {
         render_simage(images[image_bg].current, TermWin.vt, width, height, image_bg, 0);
@@ -649,11 +690,19 @@ handle_resize(unsigned int width, unsigned int height)
 void
 handle_move(int x, int y)
 {
+    int dx, dy;
+
     if ((TermWin.x != x) || (TermWin.y != y)) {
+        dx = abs(TermWin.x - x);
+        dy = abs(TermWin.y - y);
         TermWin.x = x;
         TermWin.y = y;
+        /* If we've moved an even multiple of the screen size, there's no
+           need to redraw trans/viewport images; the images will line up. */
         if (image_mode_any(MODE_TRANS | MODE_VIEWPORT)) {
-            redraw_images_by_mode(MODE_TRANS | MODE_VIEWPORT);
+            if ((dx % DisplayWidth(Xdisplay, Xscreen)) || (dy % DisplayHeight(Xdisplay, Xscreen))) {
+                redraw_images_by_mode(MODE_TRANS | MODE_VIEWPORT);
+            }
         }
     }
 }
@@ -664,7 +713,7 @@ stored_palette(char op)
 {
     static Pixel default_colors[NRS_COLORS + EXTRA_COLORS];
     static unsigned char stored = 0;
-    unsigned char i;
+    unsigned int i;
 
     if (op == SAVE) {
         for (i = 0; i < NRS_COLORS; i++) {
@@ -686,7 +735,7 @@ set_window_color(int idx, const char *color)
 
     D_X11(("idx == %d, color == \"%s\"\n", idx, NONULL(color)));
 
-    if (color == NULL || *color == '\0')
+    if (!color || *color == '\0')
         return;
 
     /* handle color aliases */
@@ -695,20 +744,23 @@ set_window_color(int idx, const char *color)
         if (i >= 8 && i <= 15) {        /* bright colors */
             i -= 8;
             PixColors[idx] = PixColors[minBright + i];
-        } else if (i >= 0 && i <= 7) { /* normal colors */
+        } else if (i >= 0 && i <= 7) {  /* normal colors */
             PixColors[idx] = PixColors[minColor + i];
         } else {
-            print_warning("Color index %d is invalid.\n", i);
+            libast_print_warning("Color index %d is invalid.\n", i);
             return;
         }
     } else if (XParseColor(Xdisplay, cmap, color, &xcol)) {
         if (!XAllocColor(Xdisplay, cmap, &xcol)) {
-            print_warning("Unable to allocate \"%s\" in the color map.\n", color);
+            libast_print_warning("Unable to allocate \"%s\" in the color map.\n", color);
             return;
         }
+        if ((idx > maxBright) && (idx < 256) && (PixColors[idx])) {
+            XFreeColors(Xdisplay, cmap, (unsigned long *) &(PixColors[idx]), 1, 0);
+        }
         PixColors[idx] = xcol.pixel;
     } else {
-        print_warning("Unable to resolve \"%s\" as a color name.\n", color);
+        libast_print_warning("Unable to resolve \"%s\" as a color name.\n", color);
         return;
     }
     set_colorfgbg();
